"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.netlifyIntegrationGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const integration_configuration_name_1 = require("../../../utils/integration-configuration-name");
const migrations_1 = require("../../../utils/migrations");
const versions_1 = require("../../../utils/versions");
function validateOptions(tree, options) {
    const config = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    if (config.projectType !== 'application') {
        throw new Error('Cannot setup netlify integration for the given project.');
    }
    if (!(0, migrations_1.isQwikNxProject)(config)) {
        throw new Error('Project contains invalid configuration. ' +
            'If you encounter this error within a Qwik project, make sure you have run necessary Nx migrations for qwik-nx plugin.');
    }
}
function getBuildSSRTargetNetlifyConfiguration(options) {
    return {
        configFile: `${options.root}/adapters/netlify/vite.config.ts`,
    };
}
/** Currently it's not possible to depend on a target with a specific configuration, that's why intermediate one is required */
function getIntermediateDependsOnTarget(options, configurationName) {
    return {
        executor: 'nx:run-commands',
        options: {
            command: `npx nx run ${options.project}:build:${configurationName}`,
        },
    };
}
function getDeployTarget(options) {
    return {
        executor: 'qwik-nx:exec',
        options: {
            command: `npx netlify deploy --build --dir=client ${options.site ? '--site=' + options.site : ''}`.trim(),
            cwd: (0, devkit_1.joinPathFragments)('dist', options.root),
        },
        dependsOn: ['build-netlify'],
    };
}
function getNetlifyPreviewTarget(options) {
    return {
        executor: 'nx:run-commands',
        options: {
            command: `npx netlify dev --dir=client`,
            cwd: (0, devkit_1.joinPathFragments)('dist', options.root),
        },
        dependsOn: ['build-netlify'],
    };
}
function normalizeOptions(tree, options) {
    const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    return Object.assign(Object.assign({}, options), { root: projectConfig.root, offsetFromRoot: (0, devkit_1.offsetFromRoot)(projectConfig.root) });
}
function installDependencies(tree) {
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, {
        'netlify-cli': versions_1.netlifyCliVersion,
    });
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign({}, (0, devkit_1.names)(options.project)), { projectRoot: options.root, offsetFromRoot: options.offsetFromRoot });
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.root, templateOptions);
    addGitIgnoreEntry(tree);
}
function addGitIgnoreEntry(tree) {
    var _a, _b;
    if (!tree.exists('.gitignore')) {
        devkit_1.logger.warn(`Couldn't find .gitignore file to update`);
        return;
    }
    let content = (_b = (_a = tree.read('.gitignore')) === null || _a === void 0 ? void 0 : _a.toString('utf-8').trimEnd()) !== null && _b !== void 0 ? _b : '';
    let gitIgnoreEntryForNetlify = '# Local Netlify folder\n.netlify\n';
    if (content) {
        gitIgnoreEntryForNetlify = '\n\n' + gitIgnoreEntryForNetlify;
    }
    if (!/\.netilify\/$/gm.test(content)) {
        content = `${content}${gitIgnoreEntryForNetlify}`;
        tree.write('.gitignore', content);
    }
}
function netlifyIntegrationGenerator(tree, schema) {
    var _a, _b;
    var _c, _d;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        validateOptions(tree, schema);
        const normalizedOptions = normalizeOptions(tree, schema);
        const config = (0, devkit_1.readProjectConfiguration)(tree, normalizedOptions.project);
        const configurationName = (0, integration_configuration_name_1.getIntegrationConfigurationName)(integration_configuration_name_1.IntegrationName.Netlify, config);
        ((_a = (_c = config.targets['build']).configurations) !== null && _a !== void 0 ? _a : (_c.configurations = {}))[configurationName] = {};
        ((_b = (_d = config.targets['build.ssr']).configurations) !== null && _b !== void 0 ? _b : (_d.configurations = {}))[configurationName] =
            getBuildSSRTargetNetlifyConfiguration(normalizedOptions);
        config.targets['build-netlify'] = getIntermediateDependsOnTarget(normalizedOptions, configurationName);
        config.targets['deploy-netlify'] = getDeployTarget(normalizedOptions);
        config.targets['preview-netlify'] =
            getNetlifyPreviewTarget(normalizedOptions);
        (0, devkit_1.updateProjectConfiguration)(tree, normalizedOptions.project, config);
        addFiles(tree, normalizedOptions);
        if (!normalizedOptions.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return installDependencies(tree);
    });
}
exports.netlifyIntegrationGenerator = netlifyIntegrationGenerator;
exports.default = netlifyIntegrationGenerator;
//# sourceMappingURL=generator.js.map